nwbwidgets.utils package
========================

Submodules
----------

nwbwidgets.utils.cmaps module
-----------------------------

.. automodule:: nwbwidgets.utils.cmaps
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.dandi module
-----------------------------

.. automodule:: nwbwidgets.utils.dandi
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.dynamictable module
------------------------------------

.. automodule:: nwbwidgets.utils.dynamictable
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.functional module
----------------------------------

.. automodule:: nwbwidgets.utils.functional
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.mpl module
---------------------------

.. automodule:: nwbwidgets.utils.mpl
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.plotly module
------------------------------

.. automodule:: nwbwidgets.utils.plotly
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.pynwb module
-----------------------------

.. automodule:: nwbwidgets.utils.pynwb
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.testing module
-------------------------------

.. automodule:: nwbwidgets.utils.testing
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.timeseries module
----------------------------------

.. automodule:: nwbwidgets.utils.timeseries
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.units module
-----------------------------

.. automodule:: nwbwidgets.utils.units
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.utils.widgets module
-------------------------------

.. automodule:: nwbwidgets.utils.widgets
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: nwbwidgets.utils
   :members:
   :undoc-members:
   :show-inheritance:
